dataset_creator package
=======================

Submodules
----------

dataset_creator.base_dataset module
-----------------------------------

.. automodule:: dataset_creator.base_dataset
    :members:
    :undoc-members:
    :show-inheritance:

dataset_creator.creator module
------------------------------

.. automodule:: dataset_creator.creator
    :members:
    :undoc-members:
    :show-inheritance:

dataset_creator.dataset module
------------------------------

.. automodule:: dataset_creator.dataset
    :members:
    :undoc-members:
    :show-inheritance:

dataset_creator.exceptions module
---------------------------------

.. automodule:: dataset_creator.exceptions
    :members:
    :undoc-members:
    :show-inheritance:

dataset_creator.genbank_fasta module
------------------------------------

.. automodule:: dataset_creator.genbank_fasta
    :members:
    :undoc-members:
    :show-inheritance:

dataset_creator.mega module
---------------------------

.. automodule:: dataset_creator.mega
    :members:
    :undoc-members:
    :show-inheritance:

dataset_creator.phylip module
-----------------------------

.. automodule:: dataset_creator.phylip
    :members:
    :undoc-members:
    :show-inheritance:

dataset_creator.tnt module
--------------------------

.. automodule:: dataset_creator.tnt
    :members:
    :undoc-members:
    :show-inheritance:

dataset_creator.utils module
----------------------------

.. automodule:: dataset_creator.utils
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: dataset_creator
    :members:
    :undoc-members:
    :show-inheritance:
